@@ -85,7 +85,12 @@ def debianize(dpath, ctx, profile=None):
             override_paths.append(profile)
         elif exists(profile):  # --profile a_file
             with open(profile) as fp:
+                set_keys = [key for (key, value) in ctx.items() if isinstance(value, set)]
                 ctx.update(load(fp))
+                # recover sets from Json lists
+                for set_key in set_keys:
+                    if not isinstance(ctx[set_key], set):
+                        ctx[set_key] = set(ctx[set_key])
         else:  # --profile name
             profile_dpath = join(PROFILES_PATH, profile)
             if isdir(profile_dpath):
@@ -104,7 +109,12 @@ def debianize(dpath, ctx, profile=None):
         fpath = join(o_dpath, 'ctx.json')
         if exists(fpath):
             with open(fpath) as fp:
+                set_keys = [key for (key, value) in ctx.items() if isinstance(value, set)]
                 ctx.update(load(fp))
+                # recover sets from Json lists
+                for set_key in set_keys:
+                    if not isinstance(ctx[set_key], set):
+                        ctx[set_key] = set(ctx[set_key])
         # invoke pre hooks
         fpath = abspath(join(o_dpath, 'hooks', 'pre'))
         if exists(fpath) and access(fpath, X_OK):
@@ -150,7 +160,8 @@ def debianize(dpath, ctx, profile=None):
         if exists(fpath) and access(fpath, X_OK):
             _dump_ctx(ctx)
             code = yield from execute([fpath, ctx['src_name'],
-                                       ctx['version'], ctx['debian_revision']],
+                                       ctx['version'], ctx['debian_revision'],
+                                       VERSION],
                                       cwd=dpath)
             if code != 0:
                 raise Exception("post hook for %s failed with %d return code" % (
@@ -175,8 +186,6 @@ def update_ctx(dpath, ctx):
 
             for fname in file_names:
                 if fname.endswith('.pyx'):
-                    if 'python' in ctx['interpreters']:
-                        ctx['build_depends'].add('cython')
                     if 'python3' in ctx['interpreters']:
                         ctx['build_depends'].add('cython3')
                     for ext in ('c', 'cpp'):
@@ -215,8 +224,6 @@ def docs(dpath, ctx, env):
             docs_pkg = 'python-{}-doc'
         elif 'python3' in ctx['interpreters']:
             docs_pkg = 'python3-{}'
-        else:
-            docs_pkg = 'python-{}'
         docs_pkg = docs_pkg.format(ctx['src_name'])
         if 'examples_dir' in docs:
             # TODO: should we extend this file only if it exists?
@@ -313,9 +320,6 @@ def control(dpath, ctx, env):
                     for interpreter in ctx['interpreters']:
                         ctx['build_depends'].add('{}-setuptools'.format(interpreter))
 
-    if 'python' in ctx['interpreters']:
-        ctx['build_depends'].add(
-            'python-all%s' % ('-dev' if ctx['binary_arch'] == 'any' else ''))
     if 'python3' in ctx['interpreters']:
         ctx['build_depends'].add(
             'python3-all%s' % ('-dev' if ctx['binary_arch'] == 'any' else ''))
@@ -347,7 +351,7 @@ def rules(dpath, ctx, env):
 
 
 def changelog(dpath, ctx, env):
-    change = ctx.get('message', 'Autogenerated by py2dsp v{}'.format(VERSION))
+    change = ctx.get('message', f"Initial release, autogenerated by py2dsp/{VERSION}; Closes: #NNNNNN")
     version = ctx['debian_version']
     distribution = ctx.get('distribution', 'UNRELEASED')
 
@@ -383,8 +387,8 @@ def changelog(dpath, ctx, env):
 @_render_template
 def copyright(dpath, ctx, env):
     if not ctx.get('deb_copyright'):
-        ctx['deb_copyright'] = "{} © {}".format(datetime.now().year, ctx['creator'])
-    if ctx['license_name'] == 'Apache 2':
+        ctx['deb_copyright'] = "{} {}".format(datetime.now().year, ctx['creator'])
+    if ctx['license_name'] in ('Apache 2', 'Apache 2.0'):
         ctx['license_name'] = 'Apache2'
         ctx['license'] = ' See /usr/share/common-licenses/Apache-2.0'
     if not ctx.get('deb_license_name'):
